#!/usr/bin/perl

use strict;
use FDN::Common::Config;
use FDN::Common::Logger;
use FDN::Web::Array;
use FDN::Web::Forms;
use FDN::Adsl::Adhs;
use FDN::Adsl::Basic;
use FDN::Adsl::Ag;
use FDN::Adsl::Utils;

sub invalide {
	my ( $info ) = @_;
	$info //= '';
	my $page = '<div style="width: 600px"><div class="error">Invalide ('.$info.')</div></div>';
	eject_page_adh($page);
	exit(0);
}

prepare_page_adh(only_for_adh => 1);
my $page;
my $annee = $vars->{'annee'};
if ( $annee !~ /^20\d\d$/ ) {
	invalide();
}

my $cfg = Config_Section('adsl/adhs/ag.cfg', 'ag-'.$annee);
if ( ! $cfg ) {
	invalide();
}

if ( $cfg->{'status'} !~ /^(open|convoc)$/ ) {
	invalide();
}


my $cid = $sess->{content}->{cid};
my $conv = convocation_par_client_id($cid);
if ( ! $conv ) {
	invalide();
}

if ( ! defined $vars->{'exercice'} ) {
	$vars->{'exercice'} = $vars->{'annee'} - 1;
}

my $form = form_read ( 'adsl/adhs/adh.cfg', 'agedit' );

# On ne peut donner procuration qu' quelqu'un qui a le droit de venir en AG.
my @clts = tous_clients_actifs();
my @presents;
for my $cl ( @clts ) {
	next if ! droit_de_vote($cl, $cfg->{'date'}, 'present');
	next if $cl->{'CLIENT_ID'} == $cid;
	next if $cl->{'CLIENT_NUMADH'} <= 0; # Pas adhrent
	next if $cl->{'CLIENT_TYPE'} =~ /(blanche|collecte)/; # Fede
	push @presents, $cl;
}
@presents = sort { $a->{'CLIENT_NOM'} cmp $b->{'CLIENT_NOM'} } @presents;
ajoute_liste_selval($form,'adsl/rewrite.tbl','lstcltsimple','client',\@presents);

if ( $cfg->{'status'} eq 'convoc' ) {
	FDN::Web::Forms::form_del_field($form,'convocation');
}

if ( $vars->{'do'} ne 'yes' ) {
	if ( ! defined $form ) {
		invalide;
		exit(0);
	}
	my $info = $conv->{'CONVOCATION_'.$annee};
	if ( $info !~ /^(papier|pdf)(:(oui|non|na))?(:(\d+|))?$/ ) {
		print STDERR "Info invalide sur la convocation: $info\n";
	}
	my ( $format, $presence, $procur ) = ( $1, $3, $5 );
	$vars->{'convocation'} = $format;
	$vars->{'presence'} = $presence // 'na';
	if ( $procur ) {
		$vars->{'client'} = $procur;
	}

	$page .= "<div style=\"width:300px\">".affiche_form($form,$vars)."</div>";
	eject_page_adh($page);
	exit(0);
}

if ( ! check_transition($form,$vars) ) {
        info 'Formulaire invalide';
        $page .= affiche_form($form,$vars);
        eject_page_adh($page);
        exit(0);
}

my $info;
my $format;
if ( $cfg->{'status'} eq 'convoc' ) {
	$conv->{'CONVOCATION_'.$annee} =~ /^(papier|pdf)/;
	$format = $1 // 'pdf';
} else {
	$format = $vars->{'convocation'};
}

my $presence = $vars->{'presence'};
my $procur = '';
if ( $presence ne 'oui' && $vars->{'client'} ) {
	$procur = ':' . $vars->{'client'};
}
$info = $format.':'.$presence.$procur;

print STDERR "Je change pour $annee -> $info\n";
set_convocation_annee($conv->{'CONVOCATION_ID'}, $annee, $info);

print "Location: adh-ag.cgi?sess=".$vars->{'sess'}."\n\n";


